# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.artifact_data_presentation import ArtifactDataPresentation

class TestArtifactDataPresentation(unittest.TestCase):
    """ArtifactDataPresentation unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ArtifactDataPresentation:
        """Test ArtifactDataPresentation
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ArtifactDataPresentation`
        """
        model = ArtifactDataPresentation()
        if include_optional:
            return ArtifactDataPresentation(
                kind = 'presentation',
                source_report_artifact_id = '',
                config = keplar_api.models.presentation_config.PresentationConfig(
                    text_amount = 'brief', 
                    image_source = 'aiGenerated', 
                    num_cards = 1.337, 
                    dimensions = 'fluid', 
                    additional_instructions = '', ),
                gamma_generation_id = '',
                pptx_gcs_path = '',
                pptx_export_url = '',
                pptx_signed_url_expires_at = '',
                pdf_gcs_path = '',
                pdf_export_url = '',
                pdf_signed_url_expires_at = '',
                pdf_conversion_started_at = ''
            )
        else:
            return ArtifactDataPresentation(
                kind = 'presentation',
                source_report_artifact_id = '',
                config = keplar_api.models.presentation_config.PresentationConfig(
                    text_amount = 'brief', 
                    image_source = 'aiGenerated', 
                    num_cards = 1.337, 
                    dimensions = 'fluid', 
                    additional_instructions = '', ),
        )
        """

    def testArtifactDataPresentation(self):
        """Test ArtifactDataPresentation"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.repdata_survey_field_details import RepdataSurveyFieldDetails

class TestRepdataSurveyFieldDetails(unittest.TestCase):
    """RepdataSurveyFieldDetails unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> RepdataSurveyFieldDetails:
        """Test RepdataSurveyFieldDetails
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `RepdataSurveyFieldDetails`
        """
        model = RepdataSurveyFieldDetails()
        if include_optional:
            return RepdataSurveyFieldDetails(
                cost = 1.337,
                abandons = 1.337,
                entrants = 1.337,
                inflight = 1.337,
                completes = 1.337,
                final_cost = 1.337,
                accepted_cost = 1.337,
                rejected_cost = 1.337,
                incidence_rate = 1.337,
                final_completes = 1.337,
                accepted_completes = 1.337,
                quality_terminates = 1.337,
                rejected_completes = 1.337,
                defender_terminates = 1.337,
                length_of_interview = 1.337,
                standard_terminates = 1.337,
                overquota_terminates = 1.337,
                accepted_unregistered_cost = 1.337,
                accepted_unregistered_completes = 1.337
            )
        else:
            return RepdataSurveyFieldDetails(
        )
        """

    def testRepdataSurveyFieldDetails(self):
        """Test RepdataSurveyFieldDetails"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from keplar_api.models.invite_with_analytics import InviteWithAnalytics
from keplar_api.models.project_config import ProjectConfig
from keplar_api.models.project_status import ProjectStatus
from keplar_api.models.user_summary import UserSummary
from typing import Optional, Set
from typing_extensions import Self

class ProjectSummaryWithAnalytics(BaseModel):
    """
    ProjectSummaryWithAnalytics
    """ # noqa: E501
    id: StrictStr
    name: StrictStr
    description: Optional[StrictStr] = None
    status: ProjectStatus
    created_at: datetime = Field(alias="createdAt")
    updated_at: datetime = Field(alias="updatedAt")
    config: ProjectConfig
    invites: List[InviteWithAnalytics]
    created_by: UserSummary = Field(alias="createdBy")
    __properties: ClassVar[List[str]] = ["id", "name", "description", "status", "createdAt", "updatedAt", "config", "invites", "createdBy"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ProjectSummaryWithAnalytics from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of config
        if self.config:
            _dict['config'] = self.config.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in invites (list)
        _items = []
        if self.invites:
            for _item_invites in self.invites:
                if _item_invites:
                    _items.append(_item_invites.to_dict())
            _dict['invites'] = _items
        # override the default output from pydantic by calling `to_dict()` of created_by
        if self.created_by:
            _dict['createdBy'] = self.created_by.to_dict()
        # set to None if description (nullable) is None
        # and model_fields_set contains the field
        if self.description is None and "description" in self.model_fields_set:
            _dict['description'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ProjectSummaryWithAnalytics from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "name": obj.get("name"),
            "description": obj.get("description"),
            "status": obj.get("status"),
            "createdAt": obj.get("createdAt"),
            "updatedAt": obj.get("updatedAt"),
            "config": ProjectConfig.from_dict(obj["config"]) if obj.get("config") is not None else None,
            "invites": [InviteWithAnalytics.from_dict(_item) for _item in obj["invites"]] if obj.get("invites") is not None else None,
            "createdBy": UserSummary.from_dict(obj["createdBy"]) if obj.get("createdBy") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.api_threads_thread_id_project_brief_document_versions_get200_response import ApiThreadsThreadIdProjectBriefDocumentVersionsGet200Response

class TestApiThreadsThreadIdProjectBriefDocumentVersionsGet200Response(unittest.TestCase):
    """ApiThreadsThreadIdProjectBriefDocumentVersionsGet200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiThreadsThreadIdProjectBriefDocumentVersionsGet200Response:
        """Test ApiThreadsThreadIdProjectBriefDocumentVersionsGet200Response
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiThreadsThreadIdProjectBriefDocumentVersionsGet200Response`
        """
        model = ApiThreadsThreadIdProjectBriefDocumentVersionsGet200Response()
        if include_optional:
            return ApiThreadsThreadIdProjectBriefDocumentVersionsGet200Response(
                versions = [
                    keplar_api.models.brief_document_version.BriefDocumentVersion(
                        doc = keplar_api.models.brief_document.BriefDocument(
                            type = 'doc', 
                            content = [
                                keplar_api.models.content_node.ContentNode()
                                ], ), 
                        version = 1.337, 
                        created_at = '', 
                        updated_at = '', )
                    ]
            )
        else:
            return ApiThreadsThreadIdProjectBriefDocumentVersionsGet200Response(
                versions = [
                    keplar_api.models.brief_document_version.BriefDocumentVersion(
                        doc = keplar_api.models.brief_document.BriefDocument(
                            type = 'doc', 
                            content = [
                                keplar_api.models.content_node.ContentNode()
                                ], ), 
                        version = 1.337, 
                        created_at = '', 
                        updated_at = '', )
                    ],
        )
        """

    def testApiThreadsThreadIdProjectBriefDocumentVersionsGet200Response(self):
        """Test ApiThreadsThreadIdProjectBriefDocumentVersionsGet200Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.user_admin_level import UserAdminLevel

class TestUserAdminLevel(unittest.TestCase):
    """UserAdminLevel unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testUserAdminLevel(self):
        """Test UserAdminLevel"""
        # inst = UserAdminLevel()

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.response_call_completed_event import ResponseCallCompletedEvent

class TestResponseCallCompletedEvent(unittest.TestCase):
    """ResponseCallCompletedEvent unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ResponseCallCompletedEvent:
        """Test ResponseCallCompletedEvent
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ResponseCallCompletedEvent`
        """
        model = ResponseCallCompletedEvent()
        if include_optional:
            return ResponseCallCompletedEvent(
                type = 'CALL_COMPLETED'
            )
        else:
            return ResponseCallCompletedEvent(
                type = 'CALL_COMPLETED',
        )
        """

    def testResponseCallCompletedEvent(self):
        """Test ResponseCallCompletedEvent"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.admin_panel_invite import AdminPanelInvite

class TestAdminPanelInvite(unittest.TestCase):
    """AdminPanelInvite unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AdminPanelInvite:
        """Test AdminPanelInvite
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AdminPanelInvite`
        """
        model = AdminPanelInvite()
        if include_optional:
            return AdminPanelInvite(
                id = '',
                name = '',
                code = '',
                status = 'PREVIEW',
                config = keplar_api.models.invite_config.InviteConfig(),
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                project = keplar_api.models.admin_panel_invite_project.AdminPanelInvite_project(
                    id = '', 
                    name = '', 
                    created_by = keplar_api.models.admin_panel_invite_project_created_by.AdminPanelInvite_project_createdBy(
                        id = '', 
                        name = '', 
                        email = '', ), )
            )
        else:
            return AdminPanelInvite(
                id = '',
                name = '',
                code = '',
                status = 'PREVIEW',
                config = keplar_api.models.invite_config.InviteConfig(),
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                project = keplar_api.models.admin_panel_invite_project.AdminPanelInvite_project(
                    id = '', 
                    name = '', 
                    created_by = keplar_api.models.admin_panel_invite_project_created_by.AdminPanelInvite_project_createdBy(
                        id = '', 
                        name = '', 
                        email = '', ), ),
        )
        """

    def testAdminPanelInvite(self):
        """Test AdminPanelInvite"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictFloat, StrictInt, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional, Union
from keplar_api.models.supported_language import SupportedLanguage
from keplar_api.models.vapi_voice import VapiVoice
from typing import Optional, Set
from typing_extensions import Self

class ProjectConversationConfig(BaseModel):
    """
    ProjectConversationConfig
    """ # noqa: E501
    first_message: StrictStr = Field(alias="firstMessage")
    end_call_message: StrictStr = Field(alias="endCallMessage")
    max_duration_seconds: Union[StrictFloat, StrictInt] = Field(alias="maxDurationSeconds")
    voice: VapiVoice
    language: Optional[SupportedLanguage] = None
    recording_format: Optional[StrictStr] = Field(default=None, alias="recordingFormat")
    __properties: ClassVar[List[str]] = ["firstMessage", "endCallMessage", "maxDurationSeconds", "voice", "language", "recordingFormat"]

    @field_validator('recording_format')
    def recording_format_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['mp3', 'wav;l16']):
            raise ValueError("must be one of enum values ('mp3', 'wav;l16')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ProjectConversationConfig from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of voice
        if self.voice:
            _dict['voice'] = self.voice.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ProjectConversationConfig from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "firstMessage": obj.get("firstMessage"),
            "endCallMessage": obj.get("endCallMessage"),
            "maxDurationSeconds": obj.get("maxDurationSeconds"),
            "voice": VapiVoice.from_dict(obj["voice"]) if obj.get("voice") is not None else None,
            "language": obj.get("language"),
            "recordingFormat": obj.get("recordingFormat")
        })
        return _obj





# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.check_permission_request import CheckPermissionRequest

class TestCheckPermissionRequest(unittest.TestCase):
    """CheckPermissionRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CheckPermissionRequest:
        """Test CheckPermissionRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CheckPermissionRequest`
        """
        model = CheckPermissionRequest()
        if include_optional:
            return CheckPermissionRequest(
                user_id = '',
                user_external_id = '',
                resource = 'thread',
                resource_id = '',
                action = 'read'
            )
        else:
            return CheckPermissionRequest(
                resource = 'thread',
                resource_id = '',
                action = 'read',
        )
        """

    def testCheckPermissionRequest(self):
        """Test CheckPermissionRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
